"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.forwardDashboardProviderRequest = void 0;
const msgbus_1 = require("@securerpc/msgbus");
const util_1 = require("util");
// NOTE This mock dashboard was copy-pasted from the dashboard tests
class MockDashboard {
    constructor(forwardProvider) {
        this.forwardProvider = forwardProvider;
    }
    connect(subscribePort) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.socket)
                return;
            this.socket = yield (0, msgbus_1.connectToMessageBusWithRetries)(subscribePort);
            this.socket.on('message', this.handleIncomingMessage.bind(this));
            this.socket.send('ready');
        });
    }
    disconnect() {
        var _a;
        (_a = this.socket) === null || _a === void 0 ? void 0 : _a.terminate();
        this.socket = undefined;
    }
    handleIncomingMessage(data) {
        return __awaiter(this, void 0, void 0, function* () {
            if (typeof data !== 'string') {
                data = data.toString();
            }
            if (!this.socket)
                return;
            const message = (0, msgbus_1.base64ToJson)(data);
            if (!(0, msgbus_1.isDashboardProviderMessage)(message))
                return;
            const responsePayload = yield (0, exports.forwardDashboardProviderRequest)(this.forwardProvider, message.payload);
            const response = {
                id: message.id,
                payload: responsePayload,
            };
            const encodedResponse = (0, msgbus_1.jsonToBase64)(response);
            this.socket.send(encodedResponse);
        });
    }
}
exports.default = MockDashboard;
const forwardDashboardProviderRequest = (provider, payload) => __awaiter(void 0, void 0, void 0, function* () {
    const send = (0, util_1.promisify)(provider.send.bind(provider));
    try {
        const response = yield send(payload);
        return response;
    }
    catch (error) {
        return {
            jsonrpc: payload.jsonrpc,
            id: payload.id,
            error,
        };
    }
});
exports.forwardDashboardProviderRequest = forwardDashboardProviderRequest;
//# sourceMappingURL=MockDashboard.js.map